@@ -25,19 +25,10 @@
 #' @import methods
 #' @import gRbase
 #'
-#' @importFrom igraph igraph.to.graphNEL igraph.from.graphNEL
+#' @importFrom igraph 
 #'     get.adjacency V "V<-" E "E<-" is.directed layout.lgl
 #'     layout.graphopt plot.igraph graph.adjacency is.dag
-#'
+#' 
 #' @importFrom broom tidy
-
-## Bioconductor imports/exports
-## ----------------------------
-
-#' @importClassesFrom graph graphNEL
-#' @importFrom graph edges nodes
-
-#' @importMethodsFrom Rgraphviz plot
-
-.dumfunction_afterimportFrom <- function(){}
+NULL
 
